#
# spec file for package python-openstackdocstheme
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-openstackdocstheme
Version:        3.2.0
Release:        1.5
Summary:        OpenStack Docs Theme
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://docs.openstack.org/openstackdocstheme
Source0:        https://files.pythonhosted.org/packages/source/o/openstackdocstheme/openstackdocstheme-3.2.0.tar.gz
BuildRequires:  openstack-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-dulwich >= 0.15.0
BuildRequires:  python3-pbr >= 2.0.0
BuildArch:      noarch

%description
Theme and extension support for Sphinx documentation that is published
to docs.openstack.org. Intended for use by OpenStack projects.

%package -n python3-openstackdocstheme
Summary:        OpenStack Docs Theme
Requires:       python3-Sphinx
Requires:       python3-dulwich >= 0.15.0

%description -n python3-openstackdocstheme
Theme and extension support for Sphinx documentation that is published
to docs.openstack.org. Intended for use by OpenStack projects.

%prep
%autosetup -p1 -n openstackdocstheme-3.2.0

# we dont need hacking or pre-commit
sed -i '/^hacking.*/d' test-requirements.txt
sed -i '/^pre-commit.*/d' test-requirements.txt
%py_req_cleanup

%build
%py3_build

%install
%py3_install

%check
PYTHONPATH=. sphinx-build -a -E -j auto -d doc/build/doctrees -b html doc/source doc/build/htm

%files -n python3-openstackdocstheme
%license LICENSE
%doc README.rst
%{_bindir}/docstheme-build-pdf
%{_bindir}/docstheme-build-translated.sh
%{_bindir}/docstheme-lang-display-name.py
%exclude %{_sysconfdir}/alternatives/*.pyc
%exclude %{_sysconfdir}/alternatives/*.pyo
%{python3_sitelib}/openstackdocstheme
%{python3_sitelib}/openstackdocstheme-*-py?.*.egg-info

%changelog
* Fri Dec  1 2023 cloud-devel@suse.de
- update to version 3.2.0
  - Fix stylesheet setting in theme.conf files
  - Sphinx 7.2.0 updates
  - Stop including Sphinx' standard JS files in script_footer.html
* Mon Jul 17 2023 cloud-devel@suse.de
- update to version 3.1.1
  - Remove errant character
  - Replace ampersand with HTML characters
  - Remove nested 'li'
  - Remove invalid attributes
  - Remove 'type' attribute of <script> element
* Mon Mar  6 2023 cloud-devel@suse.de
- update to version 3.1.0
  - Only hide top-level duplicated title
* Mon Jan  2 2023 cloud-devel@suse.de
- update to version 3.0.1
  - Update included page footers to use current URLs
* Sat Oct  1 2022 cloud-devel@suse.de
- update to version 3.0.0
  - Drop python3.6/3.7 support in testing runtime
  - Fix broken link for Marketplace in header
* Wed Jul 13 2022 Dirk Müller <dmueller@suse.com>
- update check section to not run setup.py test anymore
* Fri May 13 2022 Dirk Müller <dmueller@suse.com>
- fix build against python 3.10
* Tue May 10 2022 cloud-devel@suse.de
- update to version 2.4.0
  - Fix OpenStack project "Search" pages
  - Updated Nav Menu
* Tue Oct 26 2021 cloud-devel@suse.de
- removed 0001-sphinx-4.0-Fix-sphinx.ext.extlinks.make_link_role-ca.patch
- update to version 2.3.1
  - Inherit from base "basic" template
  - Change to OFTC
  - Page header fix with Sphinx4
  - trivial: Fix indentation
  - setup.cfg: Replace dashes with underscores
  - sphinx 4.0: Fix sphinx.ext.extlinks.make_link_role call
  - Use TOX_CONSTRAINTS_FILE
  - tox: Toggle 'usedevelop'
  - sphinx 4.0: Handle HTML 5 changes
  - Move flake8 as a pre-commit local target.
* Mon Aug  9 2021 Dirk Müller <dmueller@suse.com>
- add 0001-sphinx-4.0-Fix-sphinx.ext.extlinks.make_link_role-ca.patch:
  compat with sphinx 4.x
* Sun May  2 2021 cloud-devel@suse.de
- update to version 2.2.7
  - Adding pre-commit
  - js: Set 'LINK_SUFFIX'
  - Remove ask.o.o
  - Added styling for rST rubric directive.
  - Change name of OpenStack Foundation
  - Store empty string for release
  - js: Don't attempt to set bug, PDF links without configuration
  - trivial: Address some indentation nits
* Fri Oct  9 2020 cloud-devel@suse.de
- update to version 2.2.5
  - Provide extension version
  - Update several links
  - Show version in PDFs
  - trivial: Remove leftover Python 2 code
  - trivial: Add whitespace
  - Changing the scope of the search bar on docs.starlingx.io
  - Add py38 package metadata
  - Mark sphinx extensions thread safe
  - Fix broken URLs
  - Update hacking for Python3
  - Lower logging level of pdf-related logs
  - Add 'openstackdocs_auto_name' config option
  - Remove vendored 'native' Pygments theme
  - Add version dropdown on docs.starlingx.io
  - Use consistent logging
  - Cleanup bindep
  - Update docstheme
  - Fix hacking min version to 3.0.1
  - Add package prefixes for all config options
  - Add octaviaclient cross job
  - [ussuri][goal] Drop python 2.7 support and testing
  - Merge, rather than overwrite, LaTeX settings
  - Ignore 'last_updated' for auto-generated pages
  - Add 'openstackdocs_auto_version' config option, path checking
  - Restore configuration of 'latex_engine'
  - Do not set html_last_updated_fmt
  - Enable parallel building
  - css: Namespace Pygments stylesheet
  - Use xelatex as latex_engine
  - Fix auto_name logic
  - Add link to PDF file
  - Add cross-tests for nova
* Tue May 12 2020 cloud-devel@suse.de
- removed 0001-Catch-any-exception-when-trying-to-call-git.patch
- update to version 1.31.2
  - Catch any exception when trying to call "git"
  - Improve docs title style
  - Move version dropdown to title line
  - Fetch generated PDF files correctly
* Thu Mar 12 2020 Dirk Mueller <dmueller@suse.com>
- switch to python 3.x only client
* Wed Oct  9 2019 cloud-devel@suse.de
- added 0001-Catch-any-exception-when-trying-to-call-git.patch
- update to version 1.31.1
  - js: Remove dead or unused JS
  - Fix version dropdown
  - Make 'docstheme-build-pdf' executable
  - Add missing fonts for pdf build in Sphinx 2.0
  - Update for OpenDev change
  - Remove a heap of dead CSS rules
  - css: Use https links (StarlingX)
  - css: Don't use bold text in titles (StarlingX)
  - css: General cleanup
  - Add missing 'role="main"' attribute
  - Update api-ref location
  - Allow to override build date with SOURCE_DATE_EPOCH
  - OpenDev Migration Patch
  - Prevent InvocationError on non-existent files
  - Add 'docstheme-build-pdf' script
  - Add reno for recent CSS cleanups
  - Add table styling
  - css: Use ellipsis for long titles in sidebar (StarlingX)
  - Update API sidebar
  - css: Add symlinks for openstack logos
  - Note External Link Helper is not compatible with project only master brach
  - Removed 'combined.css' for 'starlingxdocs' theme
  - css: Move bootstrap modifications to 'combined.css' (StarlingX)
  - setup.cfg: Remove remanents of 'build_sphinx' usage
  - js: Fix some comments
  - Reference OpenStack logo in openstackdocstheme
* Mon Apr  8 2019 cloud-devel@suse.de
- update to version 1.29.2
  - Add options for sphinx-build -W in docstheme-build-translated.sh
  - Catch OSError when trying to get the last_update from git
  - Change openstack-dev to openstack-discuss
  - Add starlingxdocs theme support
  - Translations: Handle directories
  - ensure repository_name is always set
  - Do not show badge for master only repos
  - import zuul job settings from project-config
  - Fix the incorrect storyboard url
  - Fix use_storyboard
  - Silence! A sequel
  - Readd get_openstack_logo_path
  - Fix regressions introduced in 1.25.0
  - Fix project-navigator link
  - Import tools for building translated documents
  - Exit trap cleanup in docstheme-build-translated.sh
  - Make root title customizable
  - Use sphinx-build everywhere
  - Move bootstrap modifications to 'combined.css'
  - Import build-openstack-api-ref
  - log details of html context
  - pass useStoryboard to logABug
  - Add an option to disable global TOC section
  - Make a bare-bones starlingxdocs theme
  - use git modification timestamps as last-updated time for each page
  - Fix typo
  - switch documentation job to new PTI
  - Remove example of deprecated app.info
  - The theme is openstackdocs
  - Fix wrong variable in build-translated
  - css: Don't use bold text in titles
  - Silence!
  - Handle StoryBoard project groups
  - Add scripts to the head section
  - Set default paths for OpenStack
  - Do not display "latest" badge if repo is not versioned
  - css: Use ellipsis for long titles in sidebar
  - StarlingX nav fix to remove "Software Update" links
  - Update hacking version
  - Remove setup.py check from pep8 job
  - Fix build jobs
* Mon Sep  3 2018 cloud-devel@suse.de
- update to version 1.22.0
  - ignore files created during packaging
  - Move code out of '__init__'
  - Avoid text overflow in toc
  - Update the description of "giturl"
  - Updated Search widget
  - add the series name to the template context
  - Make bg color for highlighted text less bright
  - Configure additional properties
  - trivial: Generate '{project}-doc' roles, not '{project}-doc-link'
  - Mark some functions as private
  - Fix typo in logger.warning() call
  - Strip tags from titles in bugTitle and meta
  - Use metadata summary instead name for doc title
  - automatically create project doc-link roles
  - trivial: Use the 'get_html_theme_path' function
  - Relocate bug_tag in logABug generated URL
  - Make emphasize-lines more highlighted
  - Configure project name, version, release
  - Remove name from project stanza
  - fix tox python3 overrides
  - Check RST as part of linting
  - trivial: Remove cruft from 'conf.py'
  - always look for the .gitreview file in root of repo
  - Updated from global requirements
  - Handle possible exceptions when fetching version numbers
  - Added deprecation badge
- remove 0001-Fix-typo-in-logger.warning-call.patch (upstream)
* Fri Feb 23 2018 cloud-devel@suse.de
- update to version 1.18.1
  - Attempt to guess valid Git URLs
  - trivial: Remove use of 'Application.{warn,info}'
  - Remove -U from pip install
  - Adds -p option in mkdir for buildpdf tox env
  - Fix giturl parsing
  - No red with double backticks markup
  - Remove setting of version/release from releasenotes
  - Revert "Fix the incorrect git source url"
  - Add zuulv3 native job
  - Adds Turkish landing page to sidebartoc_menu
  - bindep: Add dependencies for PDFs on Fedora
  - gitignore: Ignore more files
  - Avoid tox_install.sh for constraints support
  - Do not print the release if empty
  - Fix the incorrect git source url
  - Updated from global requirements
  - Replace the http links with the right ones in docs
- Switch to stable/queens spec template
- Add 0001-Fix-typo-in-logger.warning-call.patch
* Tue Nov 21 2017 cloud-devel@suse.de
- update to version 1.17.0
  - Documents how to set conf.py for PDF generation
  - Remove navigation.html
  - Fix link to openstackdays
  - Update links in README
  - Update the configuration of generating a PDF document
  - Break cycle dependency with reno
  - Cleanup setup.cfg
  - Sync language list with openstack-manuals repo
  - Add support for sphinx sidebar role
  - [www] Fix link to COA
  - Bring back local search
  - Break cycle dependency with os-api-ref
  - Remove stray characters from demo
  - Link to latest version
  - Updated from global requirements
  - show release series names not version tags
- drop 0001-Break-cycle-dependency-with-reno.patch,
  0001-Break-cycle-dependency-with-os-api-ref.patch: upstream
* Wed Aug  9 2017 tbechtold@suse.com
- add 0001-Break-cycle-dependency-with-reno.patch
* Mon Aug  7 2017 cloud-devel@suse.de
- update to version 1.16.1
  - Fix sorting of git versions
  - Standardise header styling
  - PDF support for sample document with font
  - Enable some off-by-default checks
  - Cleanup conf.py
  - automate some of the extension setup
  - Update 2 documentation URLs according to doc migration
  - CSS: Add margin-left to <dd>
  - Fix Added / Changed / Deprecated notices
  - README: Update configuration of openstackdocstheme
  - Add note in README about Python 3 changes
  - Require bug_project setting
  - Update hacking to current version
  - Add alignment styling for figures and images
  - Change name of checkbuild testenv to buildpdf for clarity
  - Fix search.html page script errors
  - Fix missing role_id
  - Allow using openstackdocstheme without git installed
  - Updates "Contents" to "Project home page" to better match existing
  - Update css markups for newer Sphinx
  - Do not display title string of page local TOC
  - Fix links in drop-down menu under Join; add https
  - move the localtoc for the page into the sidebar
  - remove smooth scrolling
  - Add spaces in demo for deprecation notices
  - Declare parallel reading safe
  - add a comment to all output HTML pages showing the input file
  - show the current project name and version in navigation link
  - Update bootstrap and jquery files
  - Strip tags from navigation prev, next titles
  - Serve minified CSS
  - Add tox env for PDF building
  - move documentation from readme to sphinx tree
  - Adding octavia api-ref
  - Increase admonition.important contrast
  - Add warning-is-error
  - Clarify search title
  - Working on integrating options from oslosphinx theme
  - Update Site Search
  - Use new OpenStack logo and header
  - Adjust 'docs-toc a' display value
  - Use https instead of http for git.openstack.org
  - Remove duplicate search field from the left sidebar
  - Update Launchpad info
  - Adds list of versions in the "Updated" bar
  - Adds docs for release versions dropdown menu
  - Update docs
  - Remove rules linked to a "Status" ID
  - Remove getJSON function and doc-characters file
  - Minimal support for storyboard
  - switch release notes build to use openstackdocs instead of oslosphinx
  - Add note for show_other_versions
  - PDF build support >= Sphinx 1.6.1
  - fix alignment of toc tree items in sidebar
  - Adds LaTeX style file for building PDF documents
  - Fix a logic issue in the JS
  - Move from 3rd party fonts to native font stack
  - Updated from global requirements
  - Add support for versionadded and deprecated
- Add 0001-Break-cycle-dependency-with-os-api-ref.patch
* Fri Feb 10 2017 cloud-devel@suse.de
- update to version 1.6.1:
  - Add trove classifiers for Python
  - Allow to build docs without git command
  - Update test API Ref
  - Add Constraints support
  - Fix tox setup
  - Includes checklist when filing a bug for osmanuals
  - Show team and repo badges on README
  - Enable release notes translation
  - Install required packages
  - Fix typo: remove redundant 'the'
  - Updated from global requirements
  - Removed minimized files
  - Update requirements
  - [www] update page header links
* Thu Oct  6 2016 tbechtold@suse.com
- Update _service
* Wed Sep  7 2016 tbechtold@suse.com
- update to version 1.5.0
  * API References dropdown menu
  * Allow automatic toc to be disabled
* Wed Aug 10 2016 tbechtold@suse.com
- update to version 1.4.0
  * Use HTTPS for external deps
  * Increase indent level of doc top contents
  * Create empty folder for custom font files
  * Change summit video URL
  * Actually include custom JS files
  * Broken Link
  * Allow the bug title to be customisable
  * Fix text font-family of admonitions.
  * Update the Administrator Guide link
  * Add appropriate order list styles
  * Make ``something`` more highlighted
  * Allow for inclusion of custom JS files
  * Release note for new sidebar feature
  * Clarify uses for this theme
  * Update Release Notes
  * Updated from global requirements
  * Set side bar content to be configurable
  * Adds release notes items for next release
  * Allow cssfiles added by sphinx extensions
* Fri Jul 22 2016 tbechtold@suse.com
- Initial packaging (version 1.3.0)
